/// <reference types="node" />
import { Terraform, TerraformPlan, TerraformOutput, PlannedResource } from './terraform';
import { TerraformJsonConfigBackendRemote } from '../terraform-json';
import * as TerraformCloudClient from '@skorfmann/terraform-cloud';
export declare class TerraformCloudPlan implements TerraformPlan {
    readonly planFile: string;
    readonly plan: {
        [key: string]: any;
    };
    readonly url: string;
    constructor(planFile: string, plan: {
        [key: string]: any;
    }, url: string);
    get resources(): PlannedResource[];
    get applyableResources(): PlannedResource[];
    get needsApply(): boolean;
}
export interface TerraformCredentialsItem {
    token: string;
}
export interface TerraformCredentials {
    [hostname: string]: TerraformCredentialsItem;
}
export interface TerraformCredentialsFile {
    credentials: TerraformCredentials;
}
export declare class TerraformCloud implements Terraform {
    readonly workdir: string;
    readonly config: TerraformJsonConfigBackendRemote;
    private readonly terraformConfigFilePath;
    private readonly token;
    private readonly hostname;
    private readonly workspaceName;
    private readonly organizationName;
    private readonly client;
    private readonly isSpeculative;
    private configurationVersionId?;
    run?: TerraformCloudClient.Run;
    constructor(workdir: string, config: TerraformJsonConfigBackendRemote, isSpeculative?: boolean);
    isRemoteWorkspace(): Promise<boolean>;
    init(): Promise<void>;
    plan(destroy?: boolean): Promise<TerraformPlan>;
    deploy(_planFile: string, stdout: (chunk: Buffer) => any): Promise<void>;
    destroy(stdout: (chunk: Buffer) => any): Promise<void>;
    version(): Promise<string>;
    output(): Promise<{
        [key: string]: TerraformOutput;
    }>;
    private workspace;
}
